#Parameters are
#                1=temp dir containing scripts
#                2=db2 userid
#                3=db2 password

unset RETVAL

SCRIPTDIR=$1
DB2USERID=$2
DB2PASSWD=$3

echo ........................................................ 
echo LoadDB started at `date` 
echo ........................................................ 

echo Checking current userid is root. 
unset CURRENTUSER

#Multi unix compatible way of getting userid.
CURRENTUSER=`id | cut -f 1 -d ' ' | cut -f 2 -d '(' | cut -f 1 -d ')'`
if [ "${CURRENTUSER}" != "root" ]; then
  echo WARNING: Script should only be run as root, attempt was made by ${CURRENTUSER}
#  exit 1
else
  echo Userid was ok. 
fi

echo Attempting to ensure unix format of text files
tr -d '\015\032' < ${SCRIPTDIR}/geo-data.txt > ${SCRIPTDIR}/geo-data.txt.2
mv -f ${SCRIPTDIR}/geo-data.txt.2 ${SCRIPTDIR}/geo-data.txt
tr -d '\015\032' < ${SCRIPTDIR}/naics-data.txt > ${SCRIPTDIR}/naics-data.txt.2
mv -f ${SCRIPTDIR}/naics-data.txt.2 ${SCRIPTDIR}/naics-data.txt
tr -d '\015\032' < ${SCRIPTDIR}/udditype-data.txt > ${SCRIPTDIR}/udditype-data.txt.2
mv -f ${SCRIPTDIR}/udditype-data.txt.2 ${SCRIPTDIR}/udditype-data.txt
tr -d '\015\032' < ${SCRIPTDIR}/unspsc-data.txt > ${SCRIPTDIR}/unspsc-data.txt.2
mv -f ${SCRIPTDIR}/unspsc-data.txt.2 ${SCRIPTDIR}/unspsc-data.txt
tr -d '\015\032' < ${SCRIPTDIR}/unspsc7-data.txt > ${SCRIPTDIR}/unspsc7-data.txt.2
mv -f ${SCRIPTDIR}/unspsc7-data.txt.2 ${SCRIPTDIR}/unspsc7-data.txt
tr -d '\015\032' < ${SCRIPTDIR}/uddicrt.sql > ${SCRIPTDIR}/uddicrt.sql.2
mv -f ${SCRIPTDIR}/uddicrt.sql.2 ${SCRIPTDIR}/uddicrt.sql 
tr -d '\015\032' < ${SCRIPTDIR}/uddiloadbasetmodels.sql > ${SCRIPTDIR}/uddiloadbasetmodels.sql.2
mv -f ${SCRIPTDIR}/uddiloadbasetmodels.sql.2 ${SCRIPTDIR}/uddiloadbasetmodels.sql

echo Configuring directory permissions. 
chmod -R 755 ${SCRIPTDIR}
chmod 755 ${SCRIPTDIR}

echo Switching to db2 id, and launching loadDatabase.sh
if [ `uname` = "Linux" ]; then
  su - ${DB2USERID} -c "cd ${PWD}; sh ${SCRIPTDIR}/loadDataBase.sh ${SCRIPTDIR} ${DB2USERID} ${DB2PASSWD}"
  RESULT=$?
else
  su - ${DB2USERID} -c "cd ${PWD}; ksh ${SCRIPTDIR}/loadDataBase.sh ${SCRIPTDIR} ${DB2USERID} ${DB2PASSWD}"
  RESULT=$?
fi

if [ ${RESULT} != 0 ]; then
  echo ERROR: loadDatabase.sh reported an error return code of ${RESULT}
  exit 1
else
  # test if loadDatabase.sh ran ok, exit code is not passed thru su. 
  tail -1 UDDILoadDB.log | grep "Leaving loadDatabase.sh with success at" > /dev/null
  if [ $? != 0 ]; then
    echo ERROR: Failed to locate success exit code from loadDatabase.sh
    exit 1
  fi
fi

# leave a success marker in the log for the calling script.
echo LoadDB.sh finished with success at `date`
