#Params are scriptdir, dbuser, dbpassword.

SCRIPTDIR=$1
DB2USERID=$2
DB2PASSWD=$3
DBUSER=${DB2USERID}
DBPWD=${DB2PASSWD}

echo loadDatabase.sh called at `date` with dbuserid of ${DB2USERID}
echo "uid : $UID userid: $USER home: $HOME pwd: $PWD"



# SETUP DB2 ENVIRONMENT

if [ -f $HOME/sqllib/db2profile ]; then
  . $HOME/sqllib/db2profile
else
  echo ERROR: db2profile was not located as expected at $HOME/sqllib/db2profile
  exit 1
fi

                       
# VALIDATE DB2 ENVIRONMENT

echo Checking for DB2INSTANCE env var.
if [ x${DB2INSTANCE} = x"" ]; then
  echo ERROR: Script must be run within correctly initialised DB2 Environment
  exit 1
fi
echo DB2Instance env var present.

echo Checking requested userid matches the current DB2INSTANCE id
if [ x${DB2INSTANCE} != x${DB2USERID} ]; then
  echo ERROR: DB2 Instance id appears to be incorrect
  exit 1
fi
echo DB2INSTANCE env var matched requested id

db2set DB2CODEPAGE > /dev/null 2>&1
if [ $? = 0 ]; then
  #db2codepage already set to something.
  PRESETCP=`db2set DB2CODEPAGE`
  if [ x${PRESETCP} = x1208 ]; then
    echo "Codepage already set to ${PRESETCP}"
  else 
    if [ x${PRESETCP} = xUTF-8 ]; then
      echo "Codepage already set to ${PRESETCP}"
    else 
      echo "Incompatible DB2 Codepage ${PRESETCP} already set"
      echo "DB2CODEPAGE must be 1208 or UTF-8, ie DB2SET DB2CODEPAGE 1208"
      exit 1;
    fi  
  fi  
fi


# CONFIGURE DB2 ENVIRONMENT

echo "Configuring DB2 Environment"
db2set | grep DB2_INDEX_2BYTEVARLEN || ${SCRIPTDIR}/setDB2ProfileVariables.sh
db2set | grep DB2CODEPAGE || ${SCRIPTDIR}/setDB2ProfileVariables.sh

                      
# DROP OLD DATABASE   
   
echo "Calling db2 connect reset, fail ok"
db2 connect reset
RESULT=$?
echo DB2 connect reset RC:${RESULT}
      
echo "Calling db2 terminate, fail ok"
db2 terminate
RESULT=$?
echo DB2 terminate RC:${RESULT}

echo "Calling db2 force application all, fail ok"
db2 force application all
RESULT=$?
echo DB2 terminate RC:${RESULT}

echo "Delaying for 2 seconds to allow applications to stop"
sleep 2

echo "Calling db2 terminate, fail ok"
db2 terminate
RESULT=$?
echo DB2 terminate RC:${RESULT}

echo "Dropping Database, DB should always be not found."
db2 drop database uddi20
RESULT=$?
echo DB2 drop database RC:${RESULT}


# CREATE NEW DATABASE

echo "Creating Database."
db2 create database uddi20 using codeset UTF-8 territory en
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to create database cleanly. RC:${RESULT}
  exit 1
fi

echo "Connecting to Database"
db2 connect to uddi20 user ${DBUSER} using ${DBPWD} 
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to connect to database cleanly. RC:${RESULT}
  exit 1
fi

         
# CONFIGURE NEW DATABASE         
         
echo "Updating applheapsz"
MSG=`db2 update db cfg for uddi20 using applheapsz 2048 2>&1`
RESULT=$?
echo ${MSG}
if [ ${RESULT} != 0 ]; then
  if [ ${RESULT} != 2 ]; then
    echo ERROR: DB2 Failed to update applheapsz on database. RC:${RESULT}
    exit 1
  fi
  if [ ${RESULT} == 2 ]; then
    echo ${MSG} | grep SQL1363W
    WARN=$?    
    if [ ${WARN} != 0 ]; then
      # SQL1363W wasnt found.. fail on this error.
      echo ERROR: DB2 Failed to update applheapsz on database. RC:${RESULT}
      exit 1
    fi
  fi
fi

echo "Updating logfilsiz"
MSG=`db2 update db cfg for uddi20 using logfilsiz 8192 2>&1`
RESULT=$?
echo ${MSG}
if [ ${RESULT} != 0 ]; then
  if [ ${RESULT} != 2 ]; then
    echo ERROR: DB2 Failed to update logfilsiz on database. RC:${RESULT}
    exit 1
  fi
  if [ ${RESULT} == 2 ]; then
    echo ${MSG} | grep SQL1363W
    WARN=$?    
    if [ ${WARN} != 0 ]; then
      # SQL1363W wasnt found.. fail on this error.
      echo ERROR: DB2 Failed to update logfilsiz on database. RC:${RESULT}
      exit 1
    fi
  fi
fi


# ACTIVATE NEW CONFIGURATION

echo "Calling db2 connect reset"
db2 connect reset
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to reset connection. RC:${RESULT}
  exit 1
fi

echo "Terminating db2."
db2 terminate
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to terminate on request. RC:${RESULT}
  exit 1
fi

echo "Connecting to Database"
db2 connect to uddi20 user ${DBUSER} using ${DBPWD} 
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to connect to database. RC:${RESULT}
  exit 1
fi


# IMPORT DATA TO NEW DATABASE

echo "Importing uddicrt.sql"
db2 -tvf ${SCRIPTDIR}/uddicrt.sql
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to import uddicrt.sql cleanly. RC:${RESULT}
#  exit 1
fi

echo "Importing uddiloadbasetmodels.sql"
db2 -tvf ${SCRIPTDIR}/uddiloadbasetmodels.sql
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to import uddiloadbastmodels.sql cleanly. RC:${RESULT}
#  exit 1
fi

echo "Calling out to populate tables."
if [ `uname` = "Linux" ]; then
  sh ${SCRIPTDIR}/populateCatTable.sh ${SCRIPTDIR} ${DBUSER} ${DBPWD}
  RESULT=$?
else
  ksh ${SCRIPTDIR}/populateCatTable.sh ${SCRIPTDIR} ${DBUSER} ${DBPWD}
  RESULT=$?
fi

echo "Populate tables rc : ${RESULT}"
if [ ${RESULT} != 0 ]; then
  echo ERROR: populateCatTable.sh returned an error. RC:${RESULT}
#  exit 1
fi


# CLOSE CONNECTIONS TO DATABASE

echo "Calling db2 connect reset"
db2 connect reset
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to reset connection. RC:${RESULT}
  exit 1
fi
      
echo "Calling db2 terminate"
db2 terminate
RESULT=$?
if [ ${RESULT} != 0 ]; then
  echo ERROR: DB2 Failed to terminate on request. RC:${RESULT}
  exit 1
fi

   
   
# Leave a success marker in the log for calling script
echo Leaving loadDatabase.sh with success at `date`
