create table business
(
    businesskey varchar(41) not null,
    owner       varchar(765),
    operator    varchar(765),
    createdate  timestamp with default CURRENT TIMESTAMP,
    changedate  timestamp with default CURRENT TIMESTAMP,
    constraint p_business primary key (businesskey)
);

create table bservice
(
    servicekey    varchar(41) not null,
    bsbusinesskey varchar(41),
    createdate    timestamp  with default CURRENT TIMESTAMP,
    changedate    timestamp  with default CURRENT TIMESTAMP,
    seqnum        INTEGER,
    constraint p_bservice primary key (servicekey)
);

create table btemplate
(
    bindingkey   varchar(41) not null,
    btservicekey varchar(41),
    accessPoint  varchar(765),
    urltype      char(48),
    hostingRedir varchar(123),
    createdate   timestamp with default CURRENT TIMESTAMP,
    changedate   timestamp with default CURRENT TIMESTAMP,
    seqnum       INTEGER,
    constraint p_btemplate primary key (bindingkey)
);

create table tmodel
(
    tmodelkey  varchar(255) not null,
    name       varchar(765),
    owner      varchar(765),
    operator   varchar(765),
    createdate timestamp with default CURRENT TIMESTAMP,
    changedate timestamp with default CURRENT TIMESTAMP,
    deletedate timestamp,
    constraint p_tmodel primary key (tmodelkey)
);

create table nameelement
(
    parentkey varchar(41) not null,
    parentelt char(32),
    lang      varchar(17),
    name      varchar(765),
    seqnum    INTEGER
);

create table overviewdoc
(
    overviewkey varchar(41) not null,
    odparentkey varchar(41),
    odparentelt char(32)  not null,
    overviewurl varchar(765),
    constraint p_overviewdoc primary key (overviewkey)
);

create table instancedetail
(
    instdetailkey varchar(41) not null,
    idbindingkey  varchar(41),
    idtmodelkey   varchar(255),
    instanceparms varchar(765),
    seqnum        INTEGER,
    constraint p_instancedetail primary key (instdetailkey),
    constraint fid_binding foreign key (idbindingkey) references btemplate(bindingkey)
);

create table categorybag
(
    cbparentkey varchar(41) not null,
    cbparentelt char(32),
    krtModelKey varchar(255),
    keyname     varchar(765),
    keyvalue    varchar(765),
    seqnum      INTEGER
);

create table identifierbag
(
    ibparentkey varchar(41) not null,
    ibparentelt char(32),
    krtModelKey varchar(255),
    keyname     varchar(765),
    keyvalue    varchar(765),
    seqnum      INTEGER
);

create table contact
(
    contactkey      varchar(41) not null,
    ctbusinesskey   varchar(41),
    personname      varchar(765),
    usetype         varchar(765),
    seqnum          INTEGER,
    constraint p_contact primary key (contactkey),
    constraint fct_business foreign key (ctbusinesskey) references business(businesskey)
);

create table email
(
    emcontactkey varchar(41) not null,
    emailaddr    varchar(765),
    usetype      varchar(765),
    seqnum       INTEGER,
    constraint f_contact foreign key (emcontactkey) references contact(contactkey)
);

create table phone
(
    phcontactkey varchar(41) not null,
    phone        varchar(150),
    usetype      varchar(765),
    seqnum       INTEGER,
    constraint fph_contact foreign key (phcontactkey) references contact(contactkey)
);

create table address
(
    addresskey   varchar(41) not null,
    adcontactkey varchar(41),
    sortcode     varchar(30),
    usetype      varchar(765),
    adtmodelkey  varchar(255),
    seqnum       INTEGER,
    constraint p_address primary key (addresskey),
    constraint fad_contact foreign key (adcontactkey) references contact(contactkey)
);

create table addrline
(
    aladdresskey varchar(41) not null,
    addressline  varchar(240),
    keyname      VARCHAR(765),
    keyvalue     VARCHAR(765),
    seqnum       INTEGER,
    constraint fal_address foreign key (aladdresskey) references address(addresskey)
);

create table discoveryurl
(
    dubusinesskey varchar(41) not null,
    url           varchar(765),
    usetype       varchar(765),
    seqnum        INTEGER,
    constraint fdu_discoveryurl foreign key (dubusinesskey) references business(businesskey)
);

create table descr
(
    deparentkey varchar(41) not null,
    deparentelt char(32),
    lang        varchar(17),
    description varchar(765),
    seqnum      INTEGER
);

create table category
(
    name        char(8),
    code        char(32) not null,
    description char(128),
    parentCode  char(32)
);

create table validationCache
(
    tmodelkey VARCHAR(255),
    value     VARCHAR(254),
    valid     CHAR(1)
);

create table validationServices
(
    bindingkey   varchar(41) not null,
    servicekey   varchar(41),
    accessPoint  varchar(765),
    urltype      char(48),
    hostingRedir varchar(123),
    constraint p_validation primary key (bindingkey)
);

create table serviceProjection
(
    projectionKey  varchar(41) not null,
    SPBusinessKey  varchar(41) not null,
    SPServiceKey   varchar(41) not null,
    constraint     p_sprojection primary key (projectionKey)
);

create table PublisherAssertion
(
    fromKey     varchar(36)  not null,
    toKey       varchar(36)  not null,
    patModelKey varchar(41)  not null,
    keyName     varchar(765) not null,
    keyValue    varchar(765) not null,
    status      varchar(18),
    createDate  timestamp  with default CURRENT TIMESTAMP,
    changeDate  timestamp  with default CURRENT TIMESTAMP,
    seqnum      INTEGER
);

create table extcategory
(
    name        VARCHAR(128),
    tmodelkey   VARCHAR(255) not null,
    description VARCHAR(128),
    url         VARCHAR(765) NOT NULL
);

-- create Indexes                                                                                                                          ;

CREATE unique INDEX in_nameparent ON NAMEELEMENT (parentkey, parentelt, lang);

CREATE INDEX pa1 on PUBLISHERASSERTION (fromKey, toKey, patModelKey);

CREATE INDEX b1 ON BUSINESS (BUSINESSKEY ASC , CHANGEDATE ASC);

CREATE INDEX b2 ON BUSINESS (BUSINESSKEY DESC);

CREATE INDEX b3 ON BUSINESS (OWNER DESC);

CREATE INDEX b4 ON BUSINESS (OWNER);

CREATE INDEX bt1 ON BTEMPLATE (BINDINGKEY ASC, BTSERVICEKEY ASC);

CREATE INDEX bt2 ON BTEMPLATE (BINDINGKEY DESC);

CREATE INDEX bt3 ON BTEMPLATE (BTSERVICEKEY ASC, BINDINGKEY ASC);

CREATE INDEX bt4 ON BTEMPLATE (BTSERVICEKEY DESC);

CREATE INDEX bs1 ON BSERVICE (SERVICEKEY ASC, BSBUSINESSKEY ASC);

CREATE INDEX bs2 ON BSERVICE (BSBUSINESSKEY DESC);

CREATE INDEX bs3 ON BSERVICE (BSBUSINESSKEY ASC, CHANGEDATE ASC, SERVICEKEY ASC);

CREATE INDEX bs4 ON BSERVICE (BSBUSINESSKEY ASC, SERVICEKEY ASC);

CREATE INDEX bs5 ON BSERVICE (SERVICEKEY DESC);

CREATE INDEX tm1 ON TMODEL (TMODELKEY DESC);

CREATE INDEX tm2 ON TMODEL (OWNER DESC);

CREATE INDEX tm3 ON TMODEL (DELETEDATE DESC);

CREATE unique INDEX d1 ON DESCR (DEPARENTKEY DESC, deparentelt, lang);

CREATE INDEX ct1 ON CONTACT (CTBUSINESSKEY ASC, CONTACTKEY ASC);

CREATE INDEX id1 ON INSTANCEDETAIL (IDBINDINGKEY DESC);

CREATE INDEX id2 ON INSTANCEDETAIL (IDBINDINGKEY ASC, IDTMODELKEY ASC, INSTDETAILKEY ASC);

CREATE INDEX id3 ON INSTANCEDETAIL ( IDBINDINGKEY ASC, IDTMODELKEY DESC);

CREATE unique INDEX od1 ON OVERVIEWDOC (ODPARENTKEY DESC, ODPARENTELT DESC);

CREATE INDEX ib1 ON IDENTIFIERBAG (IBPARENTKEY DESC, IBPARENTELT DESC);

CREATE INDEX e1 ON EMAIL (EMCONTACTKEY ASC);

CREATE INDEX a1 ON ADDRESS (ADCONTACTKEY ASC, USETYPE ASC, SORTCODE ASC, ADDRESSKEY ASC);

CREATE INDEX durl1 ON DISCOVERYURL (DUBUSINESSKEY DESC);

CREATE INDEX p1 ON PHONE (PHCONTACTKEY ASC, USETYPE ASC, PHONE ASC);

CREATE unique INDEX al1 ON ADDRLINE (ALADDRESSKEY, SEQNUM );

CREATE INDEX al2 ON ADDRLINE (ALADDRESSKEY ASC, SEQNUM ASC, ADDRESSLINE ASC);

CREATE INDEX c1 ON CATEGORY (NAME DESC, CODE DESC);

CREATE INDEX cb1 ON CATEGORYBAG (CBPARENTKEY DESC, CBPARENTELT DESC);

commit;
